@@ -53,6 +53,7 @@ class UserDirs(object):
 				self.dir_bin = os.path.abspath(os.path.join(self.dir_home, '.local', 'bin'))
 				self.dir_icons = os.path.abspath(os.path.join(self.dir_home, '.local', 'share', 'icons'))
 				self.dir_desktop_links = os.path.abspath(os.path.join(self.dir_home, '.local', 'share', 'applications'))
+				self.dir_themes = self.dir_icons = os.path.abspath(os.path.join(self.dir_home, '.themes'))
 				self.dir_cache = os.path.abspath(os.path.join(self.dir_home, '.cache'))
 				self.dir_gnupg = os.path.abspath(os.path.join(self.dir_home, '.gnupg'))
 				self.dir_config = os.path.abspath(os.path.join(self.dir_home, '.config'))
@@ -87,7 +88,6 @@ class UserDirs(object):
 			except(FileExistsError):
 				pass
 			except(PermissionError):
-				#print(__class__.__name__, 'você não tem permissão para criar ...', d)
 				pass
 			except Exception as err:
 				from time import sleep
